lazytest.clojure-ext.core


->keywordclj

(->keyword s)

Convert strings with optional leading colons to keywords.

"foo" -> :foo ":foo" -> :foo

Convert strings with optional leading colons to keywords.

"foo" -> :foo
":foo" -> :foo
sourceraw docstring

pattern-flagsclj

source

re-compileclj

(re-compile s)
(re-compile s & flags)

Returns an instance of java.util.regex.Pattern, for use, e.g. in re-matcher.

If given only a string, acts as re-pattern. If given a string and trailing keywords, treats the keywords as java.util.regex.Pattern flags (cf. pattern-flags), using bit-and to merge them before passing them to Pattern/compile.

Returns an instance of java.util.regex.Pattern, for use, e.g. in `re-matcher`.

If given only a string, acts as `re-pattern`. If given a string and trailing keywords, treats the keywords as java.util.regex.Pattern flags (cf. [[pattern-flags]]), using `bit-and` to merge them before passing them to `Pattern/compile`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries