lazytest.extensions.cucumber

Cucumber support through lambdaisland's excellent kaocha-cucumber library. Docstrings are taken from the Cucumber documentation.

To see more details, read the official Cucumber documentation.

Cucumber support through lambdaisland's excellent kaocha-cucumber library. Docstrings are taken from the Cucumber documentation.

To see more details, read the official [Cucumber documentation](https://cucumber.io/docs/gherkin/reference).
raw docstring

lazytest.extensions.expectations

Adapts the expect assertion and utility functions from Expectations v2.

note

As of Lazytest 1.7.0, the interface vars defexpect and expecting have been marked as deprecated and will be removed in a future version. Please require them from lazytest.experimental.interfaces.expectations if you wish to continue to use them, tho take care with them being implemented to match their original behavior.

The Expectations v2 interface vars (defexpect, expecting, etc) have also been adapted. Due to the differences in Lazytest and clojure.test, test cases must be defined with lazytest.core/it, as expect is merely an assertion.

(defexpect example-test
  (expecting "many ways to work"
    (it "is a cool assertion DSL"
      (expect 2 2))))
Adapts the `expect` assertion and utility functions from [Expectations v2](https://github.com/clojure-expectations/clojure-test).

> [!NOTE]
> As of Lazytest 1.7.0, the interface vars [[defexpect]] and [[expecting]] have been marked as deprecated and _will_ be removed in a future version. Please require them from [[lazytest.experimental.interfaces.expectations]] if you wish to continue to use them, tho take care with them being implemented to match their original behavior.

The Expectations v2 interface vars (`defexpect`, `expecting`, etc) have also been adapted. Due to the differences in Lazytest and `clojure.test`, test cases must be defined with `lazytest.core/it`, as [[expect]] is merely an assertion.

```clojure
(defexpect example-test
  (expecting "many ways to work"
    (it "is a cool assertion DSL"
      (expect 2 2))))
```
raw docstring

lazytest.extensions.matcher-combinators

Wrappers around matcher-combinators library functions for use in Lazytest tests. Copies the docstrings from the matcher-combinators vars.

Wrappers around matcher-combinators library functions for use in Lazytest tests. Copies the docstrings from the matcher-combinators vars.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries