lazytest.filter


filter-suiteclj

(filter-suite suite config)

If any items in sequence s are focused, return them, with focus metadata added to the sequence; else return s unchanged.

If any items in sequence s are focused, return them, with focus
metadata added to the sequence; else return s unchanged.
sourceraw docstring

filter-treecljmultimethod

(filter-tree obj config)

If any item or sequence in the tree rooted at s has focus metadata set to true, returns just the focused items while preserving their position in the tree. Otherwise returns s unchanged.

If any item or sequence in the tree rooted at s has focus metadata
set to true, returns just the focused items while preserving their
position in the tree. Otherwise returns s unchanged.
sourceraw docstring

filter-tree-dispatchclj

(filter-tree-dispatch obj _)
source

focus-fnsclj

(focus-fns config)

Updates the provided config to have :include-fn and :exclude-fn based on :include and :exclude respectfully. When they are seqs, :include and :exclude sequences are applied to some-fn, returning a 1-arity function that checks if any of the include/exclude keywords exist on the arg.

Updates the provided config to have `:include-fn` and `:exclude-fn` based on `:include` and `:exclude` respectfully.
When they are seqs, `:include` and `:exclude` sequences are applied to `some-fn`, returning a 1-arity function that checks if any of the include/exclude keywords exist on the arg.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries