lazytest.reporters

All of the built-in reporters. Most are multimethods, but some are more simple functions, while others are vectors of reporter references (combining them to give a more traditional output).

Full reporters (includes focused, results, and summary):

  • nested: Print each suite and test case on a new line, indenting on each suite.
  • dots: Prints tests and namespaces as dots.
  • clojure-test: Prints test output similarly to clojure.test's output.
  • short: Only prints errors and the summary.

Composable reporters:

  • dots*: Prints tests and namespaces as dots (without results or summary).
  • nested*: Print each suite and test case on a new line, indenting on each suite (without results or summary).
  • focused: Prints a message before a test run when any tests are focused.
  • results: Print failed assertions, their arguments, and associated information.
  • summary: Prints the number of test cases and failures.

Utility reporters:

  • debug: Prints loudly about every step of the way. Incredibly noisy, not recommended.
  • quiet: Prints nothing. Does not prevent other reporters from printing.
All of the built-in reporters. Most are multimethods, but some are more simple functions, while others are vectors of reporter references (combining them to give a more traditional output).

Full reporters (includes `focused`, `results`, and `summary`):
* [[nested]]: Print each suite and test case on a new line, indenting on each suite.
* [[dots]]: Prints tests and namespaces as dots.
* [[clojure-test]]: Prints test output similarly to `clojure.test`'s output.
* [[short]]: Only prints errors and the summary.

Composable reporters:
* [[dots*]]: Prints tests and namespaces as dots (without results or summary).
* [[nested*]]: Print each suite and test case on a new line, indenting on each suite (without results or summary).
* [[focused]]: Prints a message before a test run when any tests are focused.
* [[results]]: Print failed assertions, their arguments, and associated information.
* [[summary]]: Prints the number of test cases and failures.

Utility reporters:
* [[debug]]: Prints loudly about every step of the way. Incredibly noisy, not recommended.
* [[quiet]]: Prints nothing. Does not prevent other reporters from printing.
raw docstring

clojure-testcljmultimethod

(clojure-test config m)

Adapts clojure.test's default reporter to Lazytests' system. It treats suite and test-case :docs as testing strings.

Example:

Testing lazytest.core-test

FAIL in (with-redefs-test) (lazytest/core_test.clj:33) redefs outside 'it' blocks should not be rebound expected: (not= 5 (plus 2 3)) actual: false

Ran 12 tests containing 29 test cases. 1 failure, 0 errors.

Adapts clojure.test's default reporter to Lazytests' system.
It treats suite and test-case :docs as testing strings.

Example:

Testing lazytest.core-test

FAIL in (with-redefs-test) (lazytest/core_test.clj:33)
redefs outside 'it' blocks should not be rebound
expected: (not= 5 (plus 2 3))
  actual: false

Ran 12 tests containing 29 test cases.
1 failure, 0 errors.
sourceraw docstring

debugcljmultimethod

(debug config m)

Prints loudly about every step of the way. Incredibly noisy, not recommended.

Prints loudly about every step of the way. Incredibly noisy, not recommended.
sourceraw docstring

dotsclj

Fully-featured dots reporter that includes focused, results, and summary.

Fully-featured dots reporter that includes focused, results, and summary.
sourceraw docstring

dots*cljmultimethod

(dots* config m)

Passing test cases are printed as ., and failures as F. Test cases in namespaces are wrapped in parentheses.

Example:

(....)(F)(.F..)

Passing test cases are printed as `.`, and failures as `F`.
Test cases in namespaces are wrapped in parentheses.

Example:

(....)(F)(.F..)
sourceraw docstring

focusedcljmultimethod

(focused config m)

Prints a message when tests are focused.

Example:

=== FOCUSED TESTS ONLY ===

Prints a message when tests are focused.

Example:

=== FOCUSED TESTS ONLY ===
sourceraw docstring

nestedclj

Fully-featured nested* reporter that includes focused, results, and summary.

Fully-featured nested* reporter that includes focused, results, and summary.
sourceraw docstring

nested*cljmultimethod

(nested* config m)

Print each suite and test case on a new line, and indent each suite.

Example:

lazytest.core-test it-test √ will early exit √ arbitrary code with-redefs-test redefs inside 'it' blocks × should be rebound FAIL redefs outside 'it' blocks √ should not be rebound

Print each suite and test case on a new line, and indent each suite.

Example:

 lazytest.core-test
   it-test
     √ will early exit
     √ arbitrary code
   with-redefs-test
     redefs inside 'it' blocks
       × should be rebound FAIL
     redefs outside 'it' blocks
       √ should not be rebound
sourceraw docstring

quietcljmultimethod

(quiet config m)

Prints nothing.

Prints nothing.
sourceraw docstring

reportclj

(report config m)
source

reporter-dispatchclj

(reporter-dispatch _config m)

A unified dispatch function for all reporters.

A unified dispatch function for all reporters.
sourceraw docstring

resultscljmultimethod

(results config m)

Print failed assertions, their arguments, and associated information.

Example:

lazytest.core-test with-redefs-test redefs inside 'it' blocks:

this should be true Expected: (= 7 (plus 2 3)) Actual: false Evaluated arguments:

  • 7
  • 6 Only in first argument: 7 Only in second argument: 6

in lazytest/core_test.clj:30

Print failed assertions, their arguments, and associated information.

Example:

lazytest.core-test
  with-redefs-test
    redefs inside 'it' blocks:

this should be true
Expected: (= 7 (plus 2 3))
Actual: false
Evaluated arguments:
 * 7
 * 6
Only in first argument:
7
Only in second argument:
6

in lazytest/core_test.clj:30
sourceraw docstring

shortclj

Only prints errors and the summary.

Only prints errors and the summary.
sourceraw docstring

summarycljmultimethod

(summary config m)

Prints the number of test cases and failures.

Example:

Ran 5 test cases in 0.04501 seconds. 0 failures.

Prints the number of test cases and failures.

Example:

Ran 5 test cases in 0.04501 seconds.
0 failures.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries