(filter-suite suite config)If any items in sequence s are focused, return them, with focus metadata added to the sequence; else return s unchanged.
If any items in sequence s are focused, return them, with focus metadata added to the sequence; else return s unchanged.
(filter-tree obj config)If any item or sequence in the tree rooted at s has focus metadata set to true, returns just the focused items while preserving their position in the tree. Otherwise returns s unchanged.
If any item or sequence in the tree rooted at s has focus metadata set to true, returns just the focused items while preserving their position in the tree. Otherwise returns s unchanged.
(focus-fns config)Updates the provided config to have :include-fn and :exclude-fn based on :include and :exclude respectfully.
When they are seqs, :include and :exclude sequences are applied to some-fn, returning a 1-arity function that checks if any of the include/exclude keywords exist on the arg.
Updates the provided config to have `:include-fn` and `:exclude-fn` based on `:include` and `:exclude` respectfully. When they are seqs, `:include` and `:exclude` sequences are applied to `some-fn`, returning a 1-arity function that checks if any of the include/exclude keywords exist on the arg.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |